==> kadaster-gds2-2.2-sources.jar: nl/kadaster/schemas/gds2/afgifte_proces/v20170401/KlantAfgiftenummerReeksType.java <==

package nl.kadaster.schemas.gds2.afgifte_proces.v20170401;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for KlantAfgiftenummerReeksType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="KlantAfgiftenummerReeksType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element name="klantAfgiftenummerVanaf" type="{http://www.w3.org/2001/XMLSchema}integer"/&amp;gt;
 *         &amp;lt;element name="klantAfgiftenummerTotmet" type="{http://www.w3.org/2001/XMLSchema}integer" minOccurs="0"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "KlantAfgiftenummerReeksType", propOrder = {
    "klantAfgiftenummerVanaf",
    "klantAfgiftenummerTotmet"
})
public class KlantAfgiftenummerReeksType {

    @XmlElement(required = true)
    protected BigInteger klantAfgiftenummerVanaf;
    protected BigInteger klantAfgiftenummerTotmet;

    /**
     * Gets the value of the klantAfgiftenummerVanaf property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getKlantAfgiftenummerVanaf() {
        return klantAfgiftenummerVanaf;
    }

    /**
     * Sets the value of the klantAfgiftenummerVanaf property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setKlantAfgiftenummerVanaf(BigInteger value) {
        this.klantAfgiftenummerVanaf = value;
    }

    /**
     * Gets the value of the klantAfgiftenummerTotmet property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getKlantAfgiftenummerTotmet() {
        return klantAfgiftenummerTotmet;
    }

    /**
     * Sets the value of the klantAfgiftenummerTotmet property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setKlantAfgiftenummerTotmet(BigInteger value) {
        this.klantAfgiftenummerTotmet = value;
    }

}

==> kadaster-gds2-3.1-sources.jar: nl/kadaster/schemas/gds2/afgifte_proces/v20170401/KlantAfgiftenummerReeksType.java <==

package nl.kadaster.schemas.gds2.afgifte_proces.v20170401;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for KlantAfgiftenummerReeksType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="KlantAfgiftenummerReeksType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="klantAfgiftenummerVanaf" type="{http://www.w3.org/2001/XMLSchema}integer"/&gt;
 *         &lt;element name="klantAfgiftenummerTotmet" type="{http://www.w3.org/2001/XMLSchema}integer" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "KlantAfgiftenummerReeksType", propOrder = {
    "klantAfgiftenummerVanaf",
    "klantAfgiftenummerTotmet"
})
public class KlantAfgiftenummerReeksType {

    @XmlElement(required = true)
    protected BigInteger klantAfgiftenummerVanaf;
    protected BigInteger klantAfgiftenummerTotmet;

    /**
     * Gets the value of the klantAfgiftenummerVanaf property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getKlantAfgiftenummerVanaf() {
        return klantAfgiftenummerVanaf;
    }

    /**
     * Sets the value of the klantAfgiftenummerVanaf property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setKlantAfgiftenummerVanaf(BigInteger value) {
        this.klantAfgiftenummerVanaf = value;
    }

    /**
     * Gets the value of the klantAfgiftenummerTotmet property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getKlantAfgiftenummerTotmet() {
        return klantAfgiftenummerTotmet;
    }

    /**
     * Sets the value of the klantAfgiftenummerTotmet property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setKlantAfgiftenummerTotmet(BigInteger value) {
        this.klantAfgiftenummerTotmet = value;
    }

}
